@@ -13,18 +13,19 @@ import re
 # take as input the location of
 class Evaluation(metaclass=ABCMeta):
     """Evaluate the different types"""
-    gs_dict_seq = dict()
-    sys_dict_seq = dict()
-    gs_dict_token = dict()
-    sys_dict_token = dict()
-    loc_list = list()
-    type_list = list()
     evaluation_type = None
     annotation = None
     col = None
 
     def __init__(self):
-        pass
+        self.gs_dict_seq = dict()
+        self.sys_dict_seq = dict()
+        self.gs_dict_token = dict()
+        self.sys_dict_token = dict()
+        self.loc_list = list()
+        self.type_list = list()
+        # noAddressType to check if participants' submission include "addressType", default is True, no addressType
+        self.noAddressType = True
 
     def convert_annotations(self, annotations):
         if self.evaluation_type == "date":
@@ -62,10 +63,8 @@ class Evaluation(metaclass=ABCMeta):
 
         self.sys_dict_seq = self.json_dict_seq(sys)
         self.gs_dict_seq = self.json_dict_seq(gs)
-        # print(self.sys_dict_seq)
         self.sys_dict_token = self.json_dict_token(sys)
         self.gs_dict_token = self.json_dict_token(gs)
-        print(self.sys_dict_token)
 
     # load the json file and convert it to a untokenised dictionary
     # with key 'noteId-start-length'
@@ -95,6 +94,8 @@ class Evaluation(metaclass=ABCMeta):
             start = anno['start']
             text = anno['text']
             # dateFormat, personType, addressType
+            # is self.annotation(dateFormat, personType, addressType) not in the
+            # JSON file, use float('nan')
             annotation_format = anno.get(self.annotation, float('nan'))
             sub_text = re.split(r'\s+', text)
             for sub in sub_text:
@@ -112,7 +113,7 @@ class Evaluation(metaclass=ABCMeta):
         final_address_eval = dict()
         final_address_eval[f"{self.evaluation_type}_location"] = self.loc_list
         final_address_eval[f"{self.evaluation_type}_type"] = self.type_list
-        print(final_address_eval)
+        # print(final_address_eval)
         # expected json object for date
         # address_loc={
         #       "metric": “F1”/“precision”/“recall”,
@@ -166,6 +167,8 @@ class Evaluation(metaclass=ABCMeta):
         fp = 0
         fn = 0
         for key in sys_dict.keys():
+            if type(sys_dict[key][1]) == str and len(sys_dict[key][1]) != 0:
+                self.noAddressType = False
             if key in gs_dict.keys() and self.format_cond(key, sys_dict, gs_dict):
                 tp = tp + 1
             else:
@@ -175,6 +178,7 @@ class Evaluation(metaclass=ABCMeta):
                     (key in sys_dict.keys() and not self.format_cond(key, sys_dict, gs_dict)):
                 fn = fn + 1
         self.print_out(tp, fp, fn, self.evaluation_type, "strict")
+        self.noAddressType = True
 
     def relax_cond(self, key, sys_dict, gs_dict):
         return abs(sys_dict[key][2]-gs_dict[key][2]) <= 2
@@ -204,7 +208,8 @@ class Evaluation(metaclass=ABCMeta):
         self.print_out(tp, fp, fn, "token", "strict")
 
     def print_out(self, tp, fp, fn, type_up, type_lower):
-        if type_up == self.evaluation_type and (self.evaluation_type == "date" or self.evaluation_type == "person"):
+        if (type_up == "date" or type_up == "person") or \
+         (type_up == "address" and self.noAddressType is True):
             precision = float('nan')
             recall = float('nan')
             F1 = float('nan')
@@ -212,8 +217,14 @@ class Evaluation(metaclass=ABCMeta):
             # precision (P): TP / (TP + FP)
             # Recall (R): TP / (TP + FN)
             # F1 score: 2 * ((P * R) / (P + R))
-            precision = round(tp / (tp + fp), 2)
-            recall = round(tp / (tp + fn), 2)
+            if tp + fp == 0:
+                precision = 0
+            else:
+                precision = round(tp / (tp + fp), 2)
+            if tp + fn == 0:
+                recall = 0
+            else:
+                recall = round(tp / (tp + fn), 2)
             if precision + recall == 0:
                 F1 = 0
             else:
